@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: index.php,v 1.2 2005/09/22 01:00:27 ryu Exp $
+  $Id: index.php,v 1.3 2005/10/28 02:48:18 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -122,8 +122,12 @@ define('TEXT_KN_MENU_GETA_THEMES_DESCRIPTION', 'Ϣ۸ѤʣУѤΥڡ뤳ȤǤޤơ̾ѹ
 
 define('TEXT_KN_MENU_HEADER_IMAGE01', 'إå');
 define('TEXT_KN_MENU_HEADER_IMAGE01_DESCRIPTION', 'å׾κ¦ˤѹ뤳ȤǤޤ<br>gifեΤѲǽǤ<br><small> jpgեѤˤʤϡ/catalog/includes/local/configure.php/admin/includes/local/configure.phpˤKN_HEADER_IMAGE01Υե̾.jpgѹɬפޤ</small>');
+define('TEXT_KN_MENU_HEADER_IMAGE01_DESCRIPTION_JPG', 'å׾κ¦ˤѹ뤳ȤǤޤ<br>jpgեΤѲǽǤ<br><small> gifեѤˤʤϡ/catalog/includes/local/configure.php/admin/includes/local/configure.phpˤKN_HEADER_IMAGE01Υե̾.gifѹɬפޤ</small>');
+define('TEXT_KN_MENU_HEADER_IMAGE01_DESCRIPTION_PNG', 'å׾κ¦ˤѹ뤳ȤǤޤ<br>pngեΤѲǽǤ<br><small> jpgեѤˤʤϡ/catalog/includes/local/configure.php/admin/includes/local/configure.phpˤKN_HEADER_IMAGE01Υե̾.jpgѹɬפޤ</small>');
 define('TEXT_KN_MENU_HEADER_IMAGE02', 'إå');
 define('TEXT_KN_MENU_HEADER_IMAGE02_DESCRIPTION', 'å׾α¦ˤѹ뤳ȤǤޤ<br>gifեΤѲǽǤ<br><small> jpgեѤˤʤϡ/catalog/includes/local/configure.php/admin/includes/local/configure.phpˤKN_HEADER_IMAGE02Υե̾.jpgѹɬפޤ</small>');
+define('TEXT_KN_MENU_HEADER_IMAGE02_DESCRIPTION_JPG', 'å׾α¦ˤѹ뤳ȤǤޤ<br>jpgեΤѲǽǤ<br><small> gifեѤˤʤϡ/catalog/includes/local/configure.php/admin/includes/local/configure.phpˤKN_HEADER_IMAGE02Υե̾.gifѹɬפޤ</small>');
+define('TEXT_KN_MENU_HEADER_IMAGE02_DESCRIPTION_PNG', 'å׾α¦ˤѹ뤳ȤǤޤ<br>pngեΤѲǽǤ<br><small> jpgեѤˤʤϡ/catalog/includes/local/configure.php/admin/includes/local/configure.phpˤKN_HEADER_IMAGE02Υե̾.jpgѹɬפޤ</small>');
 define('TEXT_KN_MENU_COLUMN_LAYOUT', '쥤');
 define('TEXT_KN_MENU_COLUMN_LAYOUT_LINK', '쥤Ȳ̤...');
 define('TEXT_KN_MENU_COLUMN_LAYOUT_DESCRIPTION', 'ξܥåɽɽǤޤ');
