@@ -1002,7 +1002,12 @@ switch ($HTTP_GET_VARS['action']) {
         if (empty($cfg_data[$i])) {
           continue;
         }
-        echo '              <tr class="dataTableRow">' . "\n";
+        $cfg_row_count++;
+        if  (($cfg_row_count/2) == floor($cfg_row_count/2)) {
+          echo '              <tr class="dataTableRowEven">' . "\n";
+        } else {
+          echo '              <tr class="dataTableRowOdd">' . "\n";
+        }
         echo '                <td align="right" class="dataTableContent">' . $cfg_data[$i][0] . "</td>\n";
         if (defined($cfg_data[$i][1])) {
           $field_name = constant($cfg_data[$i][1]);
@@ -1270,7 +1275,12 @@ switch ($HTTP_GET_VARS['action']) {
         if (empty($cfg_data[$i])) {
           continue;
         }
-        echo '              <tr class="dataTableRow">' . "\n";
+        $cfg_row_count++;
+        if  (($cfg_row_count/2) == floor($cfg_row_count/2)) {
+          echo '              <tr class="dataTableRowEven">' . "\n";
+        } else {
+          echo '              <tr class="dataTableRowOdd">' . "\n";
+        }
         echo '                <td align="right" class="dataTableContent">' . $cfg_data[$i][0] . "</td>\n";
         if (defined($cfg_data[$i][1])) {
           $field_name = constant($cfg_data[$i][1]);
