@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: checkout_process.php,v 1.1.1.1 2005/06/30 05:04:11 ryu Exp $
+  $Id: checkout_process.php,v 1.2 2005/10/28 00:52:14 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -371,11 +371,11 @@
   
   $email_order .= $email_signature;
   
-  tep_mail(tep_get_fullname($order->customer['firstname'],$order->customer['lastname']) . EMAIL_HONORIFIC, $order->customer['email_address'], $email_subject, nl2br($email_order), STORE_OWNER, STORE_OWNER_EMAIL_ADDRESS, '');
+  tep_mail(tep_get_fullname($order->customer['firstname'],$order->customer['lastname']), $order->customer['email_address'], $email_subject, nl2br($email_order), STORE_OWNER, STORE_OWNER_EMAIL_ADDRESS, '');
 
 // send emails to other people
   if (SEND_EXTRA_ORDER_EMAILS_TO != '') {
-    tep_mail('', SEND_EXTRA_ORDER_EMAILS_TO, $email_subject, nl2br($email_order), STORE_OWNER, STORE_OWNER_EMAIL_ADDRESS, '');
+    tep_mail('', SEND_EXTRA_ORDER_EMAILS_TO, $email_subject, nl2br($email_order), tep_get_fullname($order->customer['firstname'],$order->customer['lastname']) . EMAIL_HONORIFIC, $order->customer['email_address'], '');
   }
 
 // load the after_process function from the payment modules
