@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: email.php,v 1.1.1.1 2005/06/30 05:04:14 ryu Exp $
+  $Id: email.php,v 1.2 2005/10/18 09:31:42 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -514,7 +514,7 @@
       if (EMAIL_TRANSPORT == 'smtp') {
         return mail($to_addr, $subject, $this->output, 'From: ' . $from . $this->lf . 'To: ' . $to . $this->lf . implode($this->lf, $this->headers) . $this->lf . implode($this->lf, $xtra_headers));
       } else {
-        return mail($to, $subject, $this->output, 'From: '.$from.$this->lf.implode($this->lf, $this->headers).$this->lf.implode($this->lf, $xtra_headers));
+        return mail($to, $subject, $this->output, 'From: '.$from.$this->lf.implode($this->lf, $this->headers).$this->lf.implode($this->lf, $xtra_headers), '-f' . STORE_OWNER_EMAIL_ADDRESS);
       }
     }
 
